# <img src="https://uploads-ssl.webflow.com/5ea5d3315186cf5ec60c3ee4/5edf1c94ce4c859f2b188094_logo.svg" alt="Pip.Services Logo" width="200"> <br/> AI Chat Messaging in Python Changelog

## <a name="1.0.0"></a> 1.0.0 (2025-02-13)

Initial public release
